function  [X dX ddX N_design] = designc1withderivatives(d)
% returns in X a (d,1)-cycle equitable design
% 
% N_design is design size = 4+\sum_{i=3}^d i
%
% output variable dX is a ((d)*d TIMES N_design) matrix
% derivatives wrt X_i are the (i-1)*d+1 : i*d) lines of the product of this matrix by
% the  vector of evaluations of f(.) at the design X
%
% output variable ddX is a (d-1) TIMES N_design) matrix. Line i yields
% the derivatives wrt (X_j,X_i), j=1,...,i-1
%
% J. Rendas, JM Fedou, October 2013
%
if d==1
    display('designc1: input space dimension must be greater than one (aborting)')
    X = []; dX = []; ddX = []; N_design = 0;
    return
end

if d==2 % intialisation of the designs with Q_2
    % Q_2
%     sigma = [2 1];
    X = [0 0; 1 0; 0 1; 1 1]; 
    N_design = 4;
    dX_ = [-1 1 0 0; % derv wrt X_1
        0 0 -1 1];
    dX= [dX_;   % der wrt 2
        -1 0 1 0;
        0 -1 0 1];
    ddX = [1 -1 -1 1];
else
    [X_ dX_ ddX_ N_design_] = designc1withderivatives(d-1);
    N_design = N_design_ + d;
    % H_d = H_{d-1} + X_d Line(1,...,d)
    X = [ X_ zeros(N_design_,1); [ Line(d-1) ones(d,1) ]];
    if size(X,1) ~= N_design
        display('error size')
        return
    end
    dX = [];
    % derivatives wrt x_1 ... x_(d-1)
    for i=1:d-1
        dX = [dX;
            dX_((i-1)*(d-1)+1:i*(d-1), :) zeros(d-1,d);
            zeros(1,size(dX_,2)) Euclides(d,i+1)-Euclides(d,i)];
    end
    % add derivative wrt x_d
    dXd = [-MatrixM(d-1) eye(d) ];
    dX = [dX; % add derivatives wrt X_d
       dXd];
    % mixed derivatives
    % first recover all with i,j < d and pad with zeros for the new points
    ddX=[ddX_ zeros(size(ddX_,1), d)];  
    % now add new derivatives of the form X_dX_i
    for i=1:d-1
        ddX(end+1,:) = dXd(i+1,:) - dXd(i,:);
    end
    
end
end

function e = Euclides(d,i)
if i>d 
    display('wrong input i>d in Euclides')
    e=[];
    return
end
e = zeros(1,d);
e(i) = 1;
end

function M = MatrixM(d)
% auxiliar function for designc1withderivatives
if d==1
    M = eye(2);
else
    M = MatrixM(d-1);
    M =  [M zeros(d,d)
        zeros(1, size(M,2) ) Euclides(d,d)];
end
end

function [L] = Line(d)
% generates the linear design in space of dimension d
% polynomial 1+ x_1 + x_1 x_2 + ... + x_1...x_d

L = zeros(1,d);
for i=1:d
    L = [L; [  ones(1,i) zeros(1,d-i)]];
end
end

